#
# spec file for package python-emoji
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-emoji
Version:        2.12.1
Release:        1.1
Summary:        Emoji for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/carpedm20/emoji/
Source:         https://files.pythonhosted.org/packages/source/e/emoji/emoji-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions >= 4.7.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-typing_extensions >= 4.7.0
BuildArch:      noarch
%python_subpackages

%description
This Python module provides unicode emoji output for strings containing emoji codes.
In addition to the official list defined by the unicode consortium a whole bunch of aliases is defined.

Example:
>> import emoji
>> print(emoji.emojize('Python is :thumbs_up:'))
Python is 👍
>> print(emoji.emojize('Python is :thumbsup:', use_aliases=True))
Python is 👍

By default, the language is English (``language='en'``). Further supported langauges are:
* Spanish ('es')
* Portuguese ('pt')
* Italian ('it')
* French ('fr')
* German ('de')
* Farsi/Persian ('fa')
* Indonesian ('id')
* Simplified Chinese ('zh')
* Japanese ('ja')
* Korean ('ko')
* Russian ('ru')
* Arabic ('ar')
* Turkish ('tr')

%prep
%autosetup -n emoji-%{version} -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/emoji*

%check
%pytest

%files %{python_files}
%doc CHANGES.md README.rst
%license LICENSE.txt
%{python_sitelib}/emoji
%{python_sitelib}/emoji-%{version}*-info

%changelog
* Mon May 20 2024 Matthias Bach <marix@marix.org> - 2.21.1
- Update to 2.12.1
  * Require version 4.7.0+ of typing-extensions
* Mon May 20 2024 Matthias Bach <marix@marix.org> - 2.12.0
- Update to 2.12.0
  * Move type annotations inline
  * Use functools.lru_cache for looking up emoji by name with
    get_emoji_by_name()
  * Move internal functions get_emoji_unicode_dict(),
    get_aliases_unicode_dict(), _EMOJI_UNICODE and _ALIASES_UNICODE
    to testutils
  * Drop support for Python 3.6
- Added new dependency on python-typing_extensions
* Mon Apr 22 2024 Matthias Bach <marix@marix.org> - 2.11.1
- update to 2.11.1
  * Add missing stubs for purely_emoji
* Tue Mar 26 2024 Matthias Bach <marix@marix.org> - 2.11.0
- Update to 2.11.0
  * Update to Unicode v15.1
* Wed Jan 31 2024 Matthias Bach <marix@marix.org> - 2.10.1
- Update to 2.10.1
  * Fix slow import when debugging in Python 3.12
* Thu Jan 18 2024 Matthias Bach <marix@marix.org> - 2.10.0
- Update to 2.10.0
  * Added Arabic and Turkish translations.
* Wed Dec  6 2023 Matthias Bach <marix@marix.org> - 2.9.0
- Update to 2.9.0
  * Added Russian translation.
- On Leap also package this for newer Python versions.
* Thu Aug 17 2023 Matthias Bach <marix@marix.org> - 2.8.0
- Update to 2.8.0
  * Update translations to unicode release-43-1
  * Include "derived annotations"-translations from unicode CLDR
  * Fix translations for emoji that have multiple forms with/out \uFE0F
  * Remove multiple underscores __, ___, ____ and - from translations
* Tue Jul 25 2023 Matthias Bach <marix@marix.org> - 2.7.0
- Update to 2.7.0
  * Extract aliases from cheat sheet and youtube
  * Fix extracting translations from emojiterra
  * Update EMOJI_DATA with new aliases and translations
* Wed Jun 28 2023 Matthias Bach <marix@marix.org> - 2.6.0
- Update to 2.6.0
  * New function purely_emoji() | Check if a string contains only
    emojis
- Switch package to modern Python package build instead of legacy
  setup.py invocation.
* Sat Jun 17 2023 Matthias Bach <marix@marix.org> - 2.5.1
- Update to 2.5.1
  * Fix Malformed zero width joiner (\u200d) causing IndexError
* Thu Jun  8 2023 Matthias Bach <marix@marix.org> - 2.5.0
- Update to 2.5.0
  * Added support for Multi-person skintones.
  * The logic from demojize() is moved to two separate private
    function tokenize() and filter_tokens() in a new file
    emoji/tokenizer.py.
- Include the list of supported langauges in the package
  description.
* Wed May 24 2023 Matthias Bach <marix@marix.org> - 2.4.0
- Updated to 2.4.0
  * Added Japanese, Korean, Indonesian, and Simplified Chinese.
* Mon Oct 31 2022 Matthias Bach <marix@marix.org> - 2.2.0
- Update to 2.2.0
  * Add support for Unicode Version 15
* Thu Sep 22 2022 Matthias Bach <marix@marix.org> - 2.1.0
- Update to 2.1.0
  * Added Farsi support
* Mon Jul 18 2022 Matthias Bach <marix@marix.org> - 2.0.0
- Update to 2.0.0
  * Removed the old dicts EMOJI_UNICODE_, UNICODE_EMOJI_
  * Removed unused language=None parameters
  * Removed use_alias parameter
  * Removed the get_regexp method
  * Removed emoji_lis
  * Removed distinct_emoji_lis
  * Made the list of languages public:
    emoji.LANGUAGES = ['en','es','pt','it','fr','de']
- Run all tests during packaging
* Fri Mar 11 2022 Matthias Bach <marix@marix.org> - 1.7.0
- Update to 1.7.0
  * New functions emoji_list() and distinct_emoji_list() added.
  * Added deprecation warnings for several functions and variables
    that will be removed in version 2.0.0.
* Sat Jan 15 2022 Matthias Bach <marix@marix.org> - 1.6.3
- Update to 1.6.3
  * Added support for counting unique emojis
  * Improved performance of demojize()
* Fri Oct 15 2021 Matthias Bach <marix@marix.org> - 1.6.1
- Update to 1.6.1
  * New is_emoji function
  * Allow multiple aliases
  * Fix unicode of some emoji in the langauge files
* Sat Sep 18 2021 Matthias Bach <marix@marix.org> - 1.5.0
- Update to 1.5.0
  * Emojis of English version updated to the Emoji Charts v14.0
- Drop obsolete `fix-python2.patch` that has been merged upstream.
* Wed Aug  4 2021 Matthias Bach <marix@marix.org> - 1.4.2
- Update to 1.4.2
  * Added support for German naming of emojis.
  * Added support for French naming of emojis.
  * Added new function `replace_emoji` which strips emojis from
    output.
- Add patch `fix-python2.patch`: Fixes unicode emoji names on Python
  2.
* Wed Jan 27 2021 Matthias Bach <marix@marix.org> - 1.2.0
- Update to 1.2.0
  * Emojis of English version updated to the Emoji Charts v.13.1
  * Added all emoji modifiers (skin tones).
  * Added support for Italian naming of emojis.
* Sat Jan 23 2021 Matthias Bach <marix@marix.org> - 1.0.1
- Update to 1.0.1
  * Added support of Spanish naming of emojis.
  * Added support of Portuguese naming of emojis.
* Mon Aug 10 2020 Matthias Bach <marix@marix.org>
- Update to 0.6.0:
  * Add variant selector for "emojize" function allowing to choose
    between "base"(None), VS-15 ("text_type") and VS-16
    ("emoji_type")
  * Add new emoji (Added to Unicode 2019-01-27)
- Drop obsolete remove_nose.patch
* Mon Mar 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Add remove_nose.patch
* Sat Sep 14 2019 Matthias Bach <marix@marix.org>
- Update to 0.5.4:
  * :robot: has been added as an alias for :robot_face:
  * Package now officially supports Python 3.7
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.3:
  * no upstream changelog
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 0.5.2
  * no upstream changelog, see git log
- run the test suite
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.1:
  * Various small fixes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Apr 15 2018 tchvatal@suse.com
- Fix source URL to use pythonhosted without hashes
* Sun Apr 15 2018 marix@marix.org
- Updated to upstream version 0.5.0.
  + Updated emoji set.
  + New function to count emojis in a string.
- Fixed example in package description.
* Sun Apr 15 2018 marix@marix.org
- Fix source URL.
* Wed Mar 14 2018 marix@marix.org
- Adjust test execution to single-spec format.
- Properly declare the license file in the files section.
* Tue Mar 13 2018 marix@marix.org
- Initial package release.
